@@ -451,7 +451,7 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
     generator->setLineNumberWidth ( options.getNumberWidth() );
     generator->setStartingNestedLang( options.getStartNestedLang());
     generator->disableTrailingNL(options.disableTrailingNL());
-    generator->setPluginReadFile(options.getPluginReadFilePath());
+    generator->setPluginParameter(options.getPluginParameter());
 
     bool styleFileWanted = !options.fragmentOutput() || options.styleOutPathDefined();
 
@@ -639,6 +639,7 @@ int HLCmdLineApp::run ( const int argc, const char*argv[] )
     }
 
     if ( i  && !options.includeStyleDef()
+            && !options.inlineCSS()
             && styleFileWanted
             && options.formatSupportsExtStyle() ) {
         string cssOutFile=outDirectory  + options.getStyleOutFilename();
