@@ -1,33 +1,23 @@
-/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
- *   ASEnhancer.cpp
- *
- *   Copyright (C) 2014 by Jim Pattee
- *   <http://www.gnu.org/licenses/lgpl-3.0.html>
- *
- *   This file is a part of Artistic Style - an indentation and
- *   reformatting tool for C, C++, C# and Java source files.
- *   <http://astyle.sourceforge.net>
- *
- *   Artistic Style is free software: you can redistribute it and/or modify
- *   it under the terms of the GNU Lesser General Public License as published
- *   by the Free Software Foundation, either version 3 of the License, or
- *   (at your option) any later version.
- *
- *   Artistic Style is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU Lesser General Public License for more details.
- *
- *   You should have received a copy of the GNU Lesser General Public License
- *   along with Artistic Style.  If not, see <http://www.gnu.org/licenses/>.
- *
- * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
- */
+// ASEnhancer.cpp
+// Copyright (c) 2016 by Jim Pattee <jimp03@email.com>.
+// This code is licensed under the MIT License.
+// License.txt describes the conditions under which this software may be distributed.
+
+//-----------------------------------------------------------------------------
+// headers
+//-----------------------------------------------------------------------------
 
 #include "astyle/astyle.h"
 
+//-----------------------------------------------------------------------------
+// astyle namespace
+//-----------------------------------------------------------------------------
 
 namespace astyle {
+//
+//-----------------------------------------------------------------------------
+// ASEnhancer class
+//-----------------------------------------------------------------------------
 
 /**
  * ASEnhancer constructor
@@ -108,7 +98,7 @@ void ASEnhancer::init(int  _fileType,
  *
  * @param line       the original formatted line will be updated if necessary.
  */
-void ASEnhancer::enhance(string &line, bool isInNamespace, bool isInPreprocessor, bool isInSQL)
+void ASEnhancer::enhance(string& line, bool isInNamespace, bool isInPreprocessor, bool isInSQL)
 {
 	shouldUnindentLine = true;
 	shouldUnindentComment = false;
@@ -129,9 +119,9 @@ void ASEnhancer::enhance(string &line, bool isInNamespace, bool isInPreprocessor
 	}
 
 	if (line.length() == 0
-	        && ! isInEventTable
-	        && ! isInDeclareSection
-	        && ! emptyLineFill)
+	        && !isInEventTable
+	        && !isInDeclareSection
+	        && !emptyLineFill)
 		return;
 
 	// test for unindent on attached brackets
@@ -174,7 +164,7 @@ void ASEnhancer::enhance(string &line, bool isInNamespace, bool isInPreprocessor
  *
  * @param line          a reference to the line that will be converted.
  */
-void ASEnhancer::convertForceTabIndentToSpaces(string &line) const
+void ASEnhancer::convertForceTabIndentToSpaces(string& line) const
 {
 	// replace tab indents with spaces
 	for (size_t i = 0; i < line.length(); i++)
@@ -195,15 +185,14 @@ void ASEnhancer::convertForceTabIndentToSpaces(string &line) const
  *
  * @param line          a reference to the line that will be converted.
  */
-void ASEnhancer::convertSpaceIndentToForceTab(string &line) const
+void ASEnhancer::convertSpaceIndentToForceTab(string& line) const
 {
 	assert(tabLength > 0);
 
 	// replace leading spaces with tab indents
 	size_t newSpaceIndentLength = line.find_first_not_of(" \t");
 	size_t tabCount = newSpaceIndentLength / tabLength;		// truncate extra spaces
-	line.erase(0U, tabCount * tabLength);
-	line.insert(0U, tabCount, '\t');
+	line.replace(0U, tabCount * tabLength, tabCount, '\t');
 }
 
 /**
@@ -213,7 +202,7 @@ void ASEnhancer::convertSpaceIndentToForceTab(string &line) const
  * @param caseIndex     the line index of the case statement.
  * @return              the line index of the colon.
  */
-size_t ASEnhancer::findCaseColon(string  &line, size_t caseIndex) const
+size_t ASEnhancer::findCaseColon(string& line, size_t caseIndex) const
 {
 	size_t i = caseIndex;
 	bool isInQuote_ = false;
@@ -238,7 +227,8 @@ size_t ASEnhancer::findCaseColon(string  &line, size_t caseIndex) const
 				continue;                           // must close quote before continuing
 			}
 		}
-		if (line[i] == '\'' || line[i] == '\"')		// check opening quote
+		if (line[i] == '"' 		// check opening quote
+		        || (line[i] == '\'' && !isDigitSeparator(line, i)))
 		{
 			isInQuote_ = true;
 			quoteChar_ = line[i];
@@ -263,13 +253,13 @@ size_t ASEnhancer::findCaseColon(string  &line, size_t caseIndex) const
  * @param indent        the number of tabsets to insert.
  * @return              the number of characters inserted.
  */
-int ASEnhancer::indentLine(string  &line, int indent) const
+int ASEnhancer::indentLine(string& line, int indent) const
 {
 	if (line.length() == 0
-	        && ! emptyLineFill)
+	        && !emptyLineFill)
 		return 0;
 
-	size_t charsToInsert;
+	size_t charsToInsert = 0;
 
 	if (forceTab && indentLength != tabLength)
 	{
@@ -277,19 +267,19 @@ int ASEnhancer::indentLine(string  &line, int indent) const
 		convertForceTabIndentToSpaces(line);
 		// insert the space indents
 		charsToInsert = indent * indentLength;
-		line.insert(0U, charsToInsert, ' ');
+		line.insert(line.begin(), charsToInsert, ' ');
 		// replace leading spaces with tab indents
 		convertSpaceIndentToForceTab(line);
 	}
 	else if (useTabs)
 	{
 		charsToInsert = indent;
-		line.insert(0U, charsToInsert, '\t');
+		line.insert(line.begin(), charsToInsert, '\t');
 	}
 	else // spaces
 	{
 		charsToInsert = indent * indentLength;
-		line.insert(0U, charsToInsert, ' ');
+		line.insert(line.begin(), charsToInsert, ' ');
 	}
 
 	return charsToInsert;
@@ -303,7 +293,7 @@ int ASEnhancer::indentLine(string  &line, int indent) const
  * @param index         the current line index.
  * @return              true if a hit.
  */
-bool ASEnhancer::isBeginDeclareSectionSQL(string  &line, size_t index) const
+bool ASEnhancer::isBeginDeclareSectionSQL(string& line, size_t index) const
 {
 	string word;
 	size_t hits = 0;
@@ -352,7 +342,7 @@ bool ASEnhancer::isBeginDeclareSectionSQL(string  &line, size_t index) const
  * @param index         the current line index.
  * @return              true if a hit.
  */
-bool ASEnhancer::isEndDeclareSectionSQL(string  &line, size_t index) const
+bool ASEnhancer::isEndDeclareSectionSQL(string& line, size_t index) const
 {
 	string word;
 	size_t hits = 0;
@@ -401,7 +391,7 @@ bool ASEnhancer::isEndDeclareSectionSQL(string  &line, size_t index) const
  * @return     false = one-line bracket has not been reached.
  *             true  = one-line bracket has been reached.
  */
-bool ASEnhancer::isOneLineBlockReached(string &line, int startChar) const
+bool ASEnhancer::isOneLineBlockReached(string& line, int startChar) const
 {
 	assert(line[startChar] == '{');
 
@@ -439,7 +429,8 @@ bool ASEnhancer::isOneLineBlockReached(string &line, int startChar) const
 			continue;
 		}
 
-		if (ch == '"' || ch == '\'')
+		if (ch == '"'
+		        || (ch == '\'' && !isDigitSeparator(line, i)))
 		{
 			isInQuote_ = true;
 			quoteChar_ = ch;
@@ -472,7 +463,7 @@ bool ASEnhancer::isOneLineBlockReached(string &line, int startChar) const
  * parse characters in the current line to determine if an indent
  * or unindent is needed.
  */
-void ASEnhancer::parseCurrentLine(string &line, bool isInPreprocessor, bool isInSQL)
+void ASEnhancer::parseCurrentLine(string& line, bool isInPreprocessor, bool isInSQL)
 {
 	bool isSpecialChar = false;			// is a backslash escape character
 
@@ -502,7 +493,9 @@ void ASEnhancer::parseCurrentLine(string &line, bool isInPreprocessor, bool isIn
 		}
 
 		// handle quotes (such as 'x' and "Hello Dolly")
-		if (!isInComment && (ch == '"' || ch == '\''))
+		if (!isInComment
+		        && (ch == '"'
+		            || (ch == '\'' && !isDigitSeparator(line, i))))
 		{
 			if (!isInQuote)
 			{
@@ -665,7 +658,7 @@ void ASEnhancer::parseCurrentLine(string &line, bool isInPreprocessor, bool isIn
  * @param index         the current line index.
  * @return              the new line index.
  */
-size_t ASEnhancer::processSwitchBlock(string &line, size_t index)
+size_t ASEnhancer::processSwitchBlock(string& line, size_t index)
 {
 	size_t i = index;
 	bool isPotentialKeyword = isCharPotentialHeader(line, i);
@@ -754,7 +747,7 @@ size_t ASEnhancer::processSwitchBlock(string &line, size_t index)
  * @param unindent      the number of tabsets to erase.
  * @return              the number of characters erased.
  */
-int ASEnhancer::unindentLine(string  &line, int unindent) const
+int ASEnhancer::unindentLine(string& line, int unindent) const
 {
 	size_t whitespace = line.find_first_not_of(" \t");
 
@@ -800,5 +793,4 @@ int ASEnhancer::unindentLine(string  &line, int unindent) const
 	return charsToErase;
 }
 
-
 }   // end namespace astyle
