@@ -84,7 +84,7 @@ MainWindow::MainWindow(QWidget *parent)
 
     //does not work in GUI editor when adding > 10 items ?!?
     QStringList fmts;
-    fmts << "Allman" << "Banner" << "GNU" <<"Google"<< "Horstmann"<<"Lisp"<<"Java"<<"K&R"<<"Linux"<<"OTBS"<<"Pico"<<"Stroustrup"<<"VTK"<<"Whitesmith";
+    fmts << "Allman" << "Banner" << "GNU" <<"Google"<< "Horstmann"<<"Lisp"<<"Java"<<"K&R"<<"Linux"<<"Mozilla"<<"OTBS"<<"Pico"<<"Stroustrup"<<"VTK"<<"Whitesmith";
     ui->comboReformat->clear();
     ui->comboReformat->addItems(fmts);
 
@@ -666,7 +666,7 @@ void MainWindow::applyCtrlValues(highlight::CodeGenerator* generator, bool previ
 
     generator->setPrintLineNumbers( ui->cbIncLineNo->isChecked(), ui->sbLineNoStart->value());
     generator->setPrintZeroes(ui->cbPadZeroes->isEnabled() && ui->cbPadZeroes->isChecked());
-    generator->setPluginReadFile(ui->lePluginReadFilePath->text().toStdString());
+    generator->setPluginParameter(ui->lePluginReadFilePath->text().toStdString());
 
 #ifdef DATA_DIR
     QString themePath = QString("%1themes/%2.theme").arg(
@@ -1159,6 +1159,13 @@ void MainWindow::on_action_Changelog_triggered()
     show.exec();
 }
 
+void MainWindow::on_action_Plug_Ins_triggered()
+{
+    ShowTextFile show;
+    show.setFileName("README_PLUGINS");
+    show.exec();
+}
+
 void MainWindow::on_action_License_triggered()
 {
     ShowTextFile show;
